@@ -106,7 +106,10 @@ def py_to_bin_default(setuptools_project):
     
     This function is the fallback and represents the "default" naming schema.
     """
-    return 'python-%s' % setuptools_project.lower()
+    name = setuptools_project.lower()
+    if name.startswith('python-'):
+        return name
+    return 'python-%s' % name
 
 def py_to_src(setuptools_project):
     """Convert a setuptools project name to a debian source package name"""
@@ -269,25 +272,20 @@ def _get_debian_dependencies(file, extras=None, exclude_extras=None):
         pkgs = []
         for extra in req.extras:
             pkgs.append('%s-%s' % (bin_pkg, extra))
-        if not pkgs:
+        if req.specs:
+            for spec in req.specs:
+                op, version = spec
+                op = _setuptools_debian_operators[op]
+                if op is None:
+                    continue
+                dpkg_version = py_version_to_deb(version)
+                pkgs.append('%s (%s %s)' % (bin_pkg, op, dpkg_version))
+        elif not pkgs:
             pkgs = [bin_pkg]
-        for pkg in pkgs:
-            if req.specs:
-                for spec in req.specs:
-                    op, version = spec
-                    op = _setuptools_debian_operators[op]
-                    if op is None:
-                        continue
-                    dpkg_version = py_version_to_deb(version)
-                    pydeps.add('%s (%s %s)' % (pkg, op, dpkg_version))
-            else:
-                pydeps.add(pkg)
-    # Let's depend on the namespace pacakges as well.
-    # this is a pretty ugly way to get __init__.py into the namespace packages
-    # which seems to be necessary.
-    # though testing it out on ubuntu gutsy said it wasnt, it was on Debian etch
-    #
-    # Perhaps we could remove this a bit later
+        pydeps.update(pkgs)
+    # Let's depend on the namespace packages as well.
+    # This is needed to get __init__.py into the namespace packages.
+    # See https://bugs.launchpad.net/van.pydeb/+bug/619294
     namespace_pkgs = dist._get_metadata('namespace_packages.txt')
     for pkg in namespace_pkgs:
         bin_pkg = py_to_bin(pkg)
